==> oscars_mgmnt_clms-0.0.8.dev20240410+43-py3-none-any.whl: oscars_mgmnt_clms/parser/geojson.py <==
from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.filename import FilenameParser
import os
import string
import time
import geojson


class CLMSGlobalParser_GeoJSON(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in GeoJSON format (mainly Lake and River Water Level)"""

    @property
    def filetype(self) -> str:
        return "geojson"

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL_point.template")

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):
        self.fix_products(product_file_info)

        # examples of supported filenames:
        #    c_gls_WL_202310182114_1300000001574_ALTI_V2.2.0.json (lake)
        #    c_gls_WL_202310182333_0000000112081_ALTI_V2.2.0.json (river)
        fn = os.path.abspath(product_file_info.get_product_path())
        file_name = os.path.splitext(os.path.basename(fn))[0]
        file_name_parts = file_name.split("_")

        # JSON files get updates on every overpass. Filename stores the last observation timestamp.
        # To facilitate the updates of JSON metadata in ES, the timestamp is removed from the id
        del file_name_parts[3]
        values["id"] = "_".join(file_name_parts)

        with open(fn) as jsonfile:
            json = geojson.load(jsonfile)

        values["productgroupid"] = string.capwords(json.properties["basin"])
        values["processingCenter"] = "CLS"
        if "institution" in json.properties:
            if not json.properties["institution"] == "LEGOS, CLS, CNES":
                values["processingCenter"] = (
                    json.properties["institution"].split(",")[0].upper()
                )
        # no title property in GeoJSON, so let's build a reasonable title
        if "lake" in json.properties:
            values["title"] = " ".join(
                [
                    "Lake water level time series:",
                    json.properties["basin"],
                    json.properties["lake"],
                ]
            )
            values["tileid"] = json.properties["lake"]
        else:
            values["title"] = " ".join(
                [
                    "River water level time series:",
                    json.properties["basin"],
                    json.properties["river"],
                ]
            )
            values["tileid"] = json.properties["river"]

        # Lake and River water level are encoded as observation time series for a specific point location, not a raster
        (lon, lat) = json.geometry.coordinates
        values["point_lon"] = lon
        values["point_lat"] = lat

        values["conformsto"] = "https://www.opengis.net/def/crs/EPSG/0/4326"
        values["producttype"] = "WL"
        # Lake and River water level are encoded as observation time series for a specific point location, not a raster
        values["resolution"] = None

        version = file_name_parts[-1]
        values["productVersion"] = version

        values["platforms"] = ["Altimeters"]

        if "time_coverage_start" in json.properties:
            values["beginposition"] = time.strftime(
                "%Y-%m-%dT%H:%M:%SZ",
                time.strptime(
                    json.properties["time_coverage_start"], "%Y-%m-%d %H:%M:%S"
                ),
            )
            values["endposition"] = time.strftime(
                "%Y-%m-%dT%H:%M:%SZ",
                time.strptime(
                    json.properties["time_coverage_end"], "%Y-%m-%d %H:%M:%S"
                ),
            )
        else:
            values["beginposition"] = values["nominaldatetime"]
            values["endposition"] = values["nominaldatetime"]

        return values["id"]

    @staticmethod
    def fix_products(fileobject):
        import os
        import re

        for info in list(fileobject.related):
            if info.name.endswith(".json"):
                title = os.path.basename(info.name).split("_")[2].split("-")[0]
                re_match = re.search("\d", title)
                if re_match:
                    # if needed, use all characters up to first digit (eg NDVI300 -> NDVI)
                    title = title[0 : re_match.start()]

                info.title = title
                info.type = "application/geo+json"
                fileobject.related.remove(info)
                fileobject.datas.append(info)

==> oscars_mgmnt_clms-0.1.8.dev20240626+89-py3-none-any.whl: oscars_mgmnt_clms/parser/geojson.py <==
from oscars_mgmnt_clms.file_object import ObjectInfo
from oscars_mgmnt_clms.parser.filename import FilenameParser, parse_date, format_date
import os
import string
import geojson


class CLMSGlobalParser_GeoJSON(FilenameParser):
    """Parser used to build GeoJSON metadata from CLMS Global Land products in GeoJSON format (mainly Lake and River Water Level)"""

    @property
    def filetype(self) -> str:
        return "geojson"

    def __init__(self):
        super().__init__(template="CLMS_GLOBAL_point.template")

    def specific_treatment(self, product_file_info: ObjectInfo, values: dict):
        self.fix_products(product_file_info)

        # examples of supported filenames:
        #    c_gls_WL_202310182114_1300000001574_ALTI_V2.2.0.json (lake)
        #    c_gls_WL_202310182333_0000000112081_ALTI_V2.2.0.json (river)
        fn = os.path.abspath(product_file_info.get_product_path())
        file_name = os.path.splitext(os.path.basename(fn))[0]
        file_name_parts = file_name.split("_")

        # JSON files get updates on every overpass. Filename stores the last observation timestamp.
        # To facilitate the updates of JSON metadata in ES, the timestamp is removed from the id
        del file_name_parts[3]
        values["id"] = "_".join(file_name_parts)

        with open(fn) as jsonfile:
            json = geojson.load(jsonfile)

        values["productgroupid"] = string.capwords(json.properties["basin"])
        values["processingCenter"] = "CLS"
        if "institution" in json.properties:
            if not json.properties["institution"] == "LEGOS, CLS, CNES":
                values["processingCenter"] = (
                    json.properties["institution"].split(",")[0].upper()
                )
        # no title property in GeoJSON, so let's build a reasonable title
        if "lake" in json.properties:
            values["title"] = " ".join(
                [
                    "Lake water level time series:",
                    json.properties["basin"],
                    json.properties["lake"],
                ]
            )
            values["tileid"] = json.properties["lake"]
        else:
            values["title"] = " ".join(
                [
                    "River water level time series:",
                    json.properties["basin"],
                    json.properties["river"],
                ]
            )
            values["tileid"] = json.properties["river"]

        # Lake and River water level are encoded as observation time series for a specific point location, not a raster
        (lon, lat) = json.geometry.coordinates
        values["point_lon"] = lon
        values["point_lat"] = lat

        values["conformsto"] = "https://www.opengis.net/def/crs/EPSG/0/4326"
        values["producttype"] = "WL"
        # Lake and River water level are encoded as observation time series for a specific point location, not a raster
        values["resolution"] = None

        version = file_name_parts[-1]
        values["productVersion"] = version

        values["platforms"] = ["Altimeters"]

        if "time_coverage_start" in json.properties:
            values["beginposition"] = format_date(
                parse_date(json.properties["time_coverage_start"])
            )
            values["endposition"] = format_date(
                parse_date(json.properties["time_coverage_end"])
            )
        else:
            values["beginposition"] = values["nominaldatetime"]
            values["endposition"] = values["nominaldatetime"]

        return values["id"]

    @property
    def mimetype(self) -> str:
        return "application/geo+json"
